.. |pypi| image:: https://badge.fury.io/py/benzina.svg
   :target: https://pypi.python.org/pypi/benzina

.. |docs| image:: https://readthedocs.org/projects/docs/badge/?version=latest
   :target: https://benzina.readthedocs.io/en/latest

|pypi| |docs|
